@@ -247,7 +247,6 @@ maybe = {
     'l2arc/persist_l2arc_005_pos': ['FAIL', known_reason],
     'largest_pool/largest_pool_001_pos': ['FAIL', known_reason],
     'mmap/mmap_sync_001_pos': ['FAIL', known_reason],
-    'mmp/mmp_on_uberblocks': ['FAIL', known_reason],
     'pam/setup': ['SKIP', "pamtester might be not available"],
     'pool_checkpoint/checkpoint_discard_busy': ['FAIL', 11946],
     'projectquota/setup': ['SKIP', exec_reason],
@@ -366,9 +365,6 @@ elif sys.platform.startswith('linux'):
         'io/io_uring': ['SKIP', 'io_uring support required'],
         'limits/filesystem_limit': ['SKIP', known_reason],
         'limits/snapshot_limit': ['SKIP', known_reason],
-        'mmp/mmp_active_import': ['FAIL', known_reason],
-        'mmp/mmp_exported_import': ['FAIL', known_reason],
-        'mmp/mmp_inactive_import': ['FAIL', known_reason],
         'stat/statx_dioalign': ['SKIP', 'statx_reason'],
     })
 
